/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.autostart.control {
    import com.adobe.cairngorm.control.FrontController;

    import org.ow2.jonas.admin.autostart.command.*;
    import org.ow2.jonas.admin.autostart.event.*;
import org.ow2.jonas.admin.autostart.model.BuilderModelLocator;

/**
     * Bind a type of command to an action.
     */
    public class Controller extends FrontController {

        /**
         * Create an instance of the controller. Commands are initialized here.
         */
        public function Controller() {
            initialiseCommands();
        }

        /**
         * Add all the commands to the pool of commands.
         *
         * An unique ID was added to all the events in order
         * to prevent a Cairngorm issue: when a command event is dispatched,
         * every controller that registered this event type receives it, even if
         * located in another module. To prevent this from happening and triggering
         * multiple severe unexpected concurrence bugs, each event dispatched is
         * postfixed with this unique ID.
         */

        public function initialiseCommands() : void {
            // Retrieve the component model
            var model : BuilderModelLocator = BuilderModelLocator.getInstance();
            this.addCommand(BuilderEvent.EVENT_AVAILABLE_APPLI + model.componentID,
                AvailableAppliCommand);
            this.addCommand(BuilderEvent.EVENT_START_BUILD_PROCESS + model.componentID,
                StartBuildCommand);
            this.addCommand(BuilderEvent.EVENT_JONAS_VERSION + model.componentID,
                JonasVersionCommand);
            this.addCommand(BuilderEvent.EVENT_DOWNLOAD_FILE + model.componentID,
                DownloadFileCommand);
            this.addCommand(BuilderEvent.EVENT_DOWNLOAD_ZIP_FILE + model.componentID,
                DownloadZipFileCommand);
            this.addCommand(BuilderEvent.EVENT_GET_OUTPUT_CONTENT + model.componentID,
                GetOutputContentCommand);
            this.addCommand(BuilderEvent.EVENT_SAVE_STARTER_INFO_IN_FILE + model.componentID,
                SaveStarterCommand);
            this.addCommand(BuilderEvent.EVENT_LOAD_STARTERS + model.componentID,
                LoadStartersCommand);
            this.addCommand(BuilderEvent.EVENT_JONAS_SERVICES + model.componentID,
                GetJonasServicesCommand);
            this.addCommand(BuilderEvent.EVENT_IS_VALID_URL + model.componentID,
                IsValidUrlCommand);
            this.addCommand(BuilderEvent.EVENT_SET_STARTER_PATH + model.componentID,
                SetStartersPathCommand);
            this.addCommand(BuilderEvent.EVENT_DELETE_STARTER + model.componentID,
                DeleteStarterCommand);
            this.addCommand(BuilderEvent.EVENT_JONAS_FOLDERS + model.componentID,
                GetJonasFoldersCommand);
            this.addCommand(BuilderEvent.EVENT_STOP_BUILD_PROCESS + model.componentID,
                StopBuildCProcessCommand);
        }
    }
}
